# -*- coding: utf-8 -*-

from random import randint



def load_dico(file_name):
    """Load and return a dictionary from file. 

    Keyword arguments:
        file_name (string) -- name of the file, may contains the path,
            otherwise the file must be in the same directory.

    Return value:
        (list(str)) -- a list of strings containing each word read in the 
            file.
    """
    dico = []
    f = open(file_name)
    for word in f.readlines():
        dico.append(word.strip())
    return dico



def get_dices():
    """Return a list of 16 dices.

    Keyword arguments:
        (None) -- Nothing.

    Return value:
        (list(str)) -- a list containing 16 strings. Each string contains 6 
            characters representing each face of a dice.
    """
    return  [ "LENUYG", "ELUPST", "ZDVNEA", "SDTNOE",
              "AMORIS", "FXRAOI", "MOQABJ", "FSHEEI",
              "HRSNEI", "ETNKOU", "TARILB", "TIEAOA",
              "ACEPDM", "RLASEC", "ULIWER", "VGTNIE"  ]



def show_grid(grid):
    """Print the grid on the screen.

    Keyword arguments:
        grid (list(list(str))) -- list of list containing the characters of 
            the grid to display.

    Return value:
        (None) -- Nothing.
    """
    for line in grid:
        for char in line:
            print(char,end=' ')
        print()



def ask_yes_no(message):
    """Return 'True' if a user's answer to the message received in arameter 
            is 'o', and 'False' if it's answer is 'n'. The question is asked 
            until the answer is either 'o' or 'n'.

    Keyword arguments:
        message(str) -- string containing the question to display to the user.

    Return value:
        (boolean) -- True if the answer is 'o', False otherwise.
    """
    answer = input(message+" o/n ").lower()
    while answer != "o" and answer != "n":
        answer = input(message+" o/n ").lower()
    return answer == "o"
